bayespy.inference.vmp.transformations.RotateGaussianMarkovChain.__init__
========================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianMarkovChain.__init__